## Recent Changes
0.0.6 - 2020-06-07

- Bugfix- Issue- Skip pattern matching start of code ignored.

0.0.5 - 2020-04-20

- Bugfix- Issue- Won't fail if Python code block doesn't print.
- Bugfix- Issue- README Travis CI example missing "install:".
- Add Development tools API section to the documentation.
- Pin phmdoctest dependency version ranges in setup.py.

0.0.4 - 2020-04-02

- Changes to build documentation on readthedocs.org.
- Inspection fixes.

0.0.3 - 2020-03-18

- Initial upload to Python Package Index.
